@@ -17,11 +17,11 @@ Mail::SPF - An object-oriented implementation of Sender Policy Framework
 
 =head1 VERSION
 
-2.009
+version 3.20240827
 
 =cut
 
-our $VERSION = '3.20240617'; # VERSION
+our $VERSION = '3.20240827'; # VERSION
 
 use warnings;
 use strict;
