@@ -2,9 +2,9 @@
 # Mail::SPF::Mech::PTR
 # SPF record "ptr" mechanism class.
 #
-# (C) 2005-2008 Julian Mehnle <julian@mehnle.net>
+# (C) 2005-2012 Julian Mehnle <julian@mehnle.net>
 #     2005      Shevek <cpan@anarres.org>
-# $Id: PTR.pm 50 2008-08-17 21:28:15Z Julian Mehnle $
+# $Id: PTR.pm 57 2012-01-30 08:15:31Z julian $
 #
 ##############################################################################
 
@@ -14,6 +14,10 @@ package Mail::SPF::Mech::PTR;
 
 Mail::SPF::Mech::PTR - SPF record C<ptr> mechanism class
 
+=head1 VERSION
+
+version 3.20240827
+
 =cut
 
 use warnings;
@@ -153,7 +157,7 @@ sub match {
 
 L<Mail::SPF>, L<Mail::SPF::Record>, L<Mail::SPF::Term>, L<Mail::SPF::Mech>
 
-L<http://www.ietf.org/rfc/rfc4408.txt>
+L<http://tools.ietf.org/html/rfc4408>
 
 For availability, support, and license information, see the README file
 included with Mail::SPF.
