@@ -2,9 +2,9 @@
 # Mail::SPF::Mod
 # SPF record modifier class.
 #
-# (C) 2005-2008 Julian Mehnle <julian@mehnle.net>
+# (C) 2005-2012 Julian Mehnle <julian@mehnle.net>
 #     2005      Shevek <cpan@anarres.org>
-# $Id: Mod.pm 50 2008-08-17 21:28:15Z Julian Mehnle $
+# $Id: Mod.pm 57 2012-01-30 08:15:31Z julian $
 #
 ##############################################################################
 
@@ -14,6 +14,10 @@ package Mail::SPF::Mod;
 
 Mail::SPF::Mod - SPF record modifier base class
 
+=head1 VERSION
+
+version 3.20240827
+
 =cut
 
 use warnings;
@@ -364,7 +368,7 @@ L<Mail::SPF::Mod::Redirect>, L<Mail::SPF::Mod::Exp>
 
 L<Mail::SPF>, L<Mail::SPF::Record>, L<Mail::SPF::Term>
 
-L<http://www.ietf.org/rfc/rfc4408.txt>
+L<http://tools.ietf.org/html/rfc4408>
 
 For availability, support, and license information, see the README file
 included with Mail::SPF.
