@@ -2,9 +2,9 @@
 # Mail::SPF::Term
 # SPF record term class.
 #
-# (C) 2005-2008 Julian Mehnle <julian@mehnle.net>
+# (C) 2005-2012 Julian Mehnle <julian@mehnle.net>
 #     2005      Shevek <cpan@anarres.org>
-# $Id: Term.pm 50 2008-08-17 21:28:15Z Julian Mehnle $
+# $Id: Term.pm 57 2012-01-30 08:15:31Z julian $
 #
 ##############################################################################
 
@@ -14,6 +14,10 @@ package Mail::SPF::Term;
 
 Mail::SPF::Term - SPF record term class
 
+=head1 VERSION
+
+version 3.20240827
+
 =cut
 
 use warnings;
@@ -282,7 +286,7 @@ I<Abstract>.  Returns the name of the term.
 
 L<Mail::SPF>, L<Mail::SPF::Record>, L<Mail::SPF::Mech>, L<Mail::SPF::Mod>
 
-L<http://www.ietf.org/rfc/rfc4408.txt>
+L<http://tools.ietf.org/html/rfc4408>
 
 For availability, support, and license information, see the README file
 included with Mail::SPF.
