@@ -2,9 +2,9 @@
 # Mail::SPF::v1::Record
 # SPFv1 record class.
 #
-# (C) 2005-2008 Julian Mehnle <julian@mehnle.net>
+# (C) 2005-2012 Julian Mehnle <julian@mehnle.net>
 #     2005      Shevek <cpan@anarres.org>
-# $Id: Record.pm 50 2008-08-17 21:28:15Z Julian Mehnle $
+# $Id: Record.pm 57 2012-01-30 08:15:31Z julian $
 #
 ##############################################################################
 
@@ -14,6 +14,10 @@ package Mail::SPF::v1::Record;
 
 Mail::SPF::v1::Record - SPFv1 record class
 
+=head1 VERSION
+
+version 3.20240827
+
 =cut
 
 use warnings;
@@ -93,7 +97,7 @@ C<helo> and C<mfrom> scopes, this option must either be exactly B<['helo',
 sub new {
     my ($self, %options) = @_;
     $self = $self->SUPER::new(%options);
-    
+
     if (defined(my $scopes = $self->{scopes})) {
         @$scopes > 0
             or throw Mail::SPF::EInvalidScope('No scopes for v=spf1 record');
@@ -105,7 +109,7 @@ sub new {
             or throw Mail::SPF::EInvalidScope(
                 "Invalid set of scopes " . join(', ', map("'$_'", @$scopes)) . " for v=spf1 record");
     }
-    
+
     return $self;
 }
 
@@ -168,7 +172,7 @@ Returns B<'v=spf1'>.
 L<Mail::SPF>, L<Mail::SPF::Record>, L<Mail::SPF::Term>, L<Mail::SPF::Mech>,
 L<Mail::SPF::Mod>
 
-L<http://www.ietf.org/rfc/rfc4408.txt>
+L<http://tools.ietf.org/html/rfc4408>
 
 For availability, support, and license information, see the README file
 included with Mail::SPF.
